#coding:utf-8
from __future__ import division
from __future__ import unicode_literals
import psychopy.visual
import psychopy.event
import psychopy.core
import codecs
import random # 疑似乱数の発生や無作為な並び替えなどを行う

conditions = [] # 空リストを用意しappend()で条件を加えていく
for stim1_lum in [-0.3, 0.3]:
    for probe_lum_index in range(9):
        probe_lum = 0.05*(probe_lum_index-4)
        conditions.append([stim1_lum, probe_lum])

conditions *= 5 # リストの内容を5回繰り返す
random.shuffle(conditions) # 無作為な順序に並び替える

win = psychopy.visual.Window(fullscr=True,
    monitor='defaultMonitor', units='cm', color='black')
clock = psychopy.core.Clock()

stim1 = psychopy.visual.Rect( # fillColorは各試行開始時に指定する
    win, width=6.0, height=6.0, pos=[-4,0], lineColor=None)
stim2 = psychopy.visual.Rect( # stim2のfillColorは固定
    win, width=3.0, height=3.0, pos=[-4,0], 
    lineColor=None, fillColor=[0.0, 0.0, 0.0])
probe = psychopy.visual.Rect(
    win, width=3.0, height=3.0, pos=[4,0], lineColor=None)

datafile = codecs.open('data.csv','w','utf-8')
datafile.write('Stim1,Probe,Response,RT\n') # ヘッダを出力しておく

for condition in conditions: # conditionsから各試行の条件を取り出す
    # 刺激色を更新する
    stim1_lum = condition[0]
    probe_lum = condition[1]
    stim1.setFillColor([stim1_lum, stim1_lum, stim1_lum])
    probe.setFillColor([probe_lum, probe_lum, probe_lum])
    
    waiting_keypress = True
    psychopy.event.getKeys() # 試行開始前のキー押しを取得しておく
    clock.reset()
    while waiting_keypress:
        keys = psychopy.event.getKeys(timeStamped=clock)
        for key in keys:
            if key[0]=='left' or key[0]=='right':
                datafile.write( # 刺激のパラメータと反応を出力
                    '{:.1f},{:.1f},{},{:.3f}\n'.format(
                        stim1_lum, probe_lum, key[0], key[1]))
                datafile.flush() # 直ちにファイルに書き出す
                waiting_keypress = False
                break
            elif key[0]=='escape': # ESCキーが押された場合は
                datafile.close()   # 直ちに終了する
                psychopy.core.exit()
        stim1.draw()
        stim2.draw()
        probe.draw()

        win.flip()

    win.flip() #刺激を消去する
    psychopy.core.wait(1.0) #1.0秒待つ

datafile.close() #データファイルを閉じる