#coding:utf-8
from __future__ import division
from __future__ import unicode_literals
import psychopy.visual
import psychopy.event
import psychopy.core
import codecs
import random

conditions = []
for stim1_lum in [-0.3, 0.3]:
    for probe_lum in [-0.9, 0.9]:
        if probe_lum == -0.9:
            series = 'up'
        else:
            series = 'down'
        conditions.append([stim1_lum, probe_lum, series])

conditions *= 5 # リストの内容を5回繰り返す
random.shuffle(conditions) # 無作為な順序に並び替える

win = psychopy.visual.Window(
    monitor='defaultMonitor', units='cm', color='black')
clock = psychopy.core.Clock()

stim1 = psychopy.visual.Rect( # fillColorは各試行開始時に指定する
    win, width=6.0, height=6.0, pos=[-4,0], lineColor=None)
stim2 = psychopy.visual.Rect( # stim2のfillColorは固定
    win, width=3.0, height=3.0, pos=[-4,0], 
    lineColor=None, fillColor=[0.0, 0.0, 0.0])
probe = psychopy.visual.Rect(
    win, width=3.0, height=3.0, pos=[4,0], lineColor=None)

datafile = codecs.open('data.csv','w','utf-8')
datafile.write('Stim1,Probe_Start,Step,Probe\n') # ヘッダを出力しておく

for condition in conditions: # conditionsから各試行の条件を取り出す
    # 刺激色を更新する
    stim1_lum = condition[0]
    probe_lum = condition[1]
    stim1.setFillColor([stim1_lum, stim1_lum, stim1_lum])
    probe.setFillColor([probe_lum, probe_lum, probe_lum])
    series = condition[2]  # この行以降を追加
    if series == 'down':   # 下降系列
        step = -0.05       # 変化量はマイナス
    else:                  # 上昇系列
        step = 0.05        # 変化量はプラス
    
    start_probe_lum = probe_lum # 開始前にstart_probe_lumに値を複製
    in_series = True
    psychopy.event.getKeys()
    while in_series:
        stim1.draw() # ここで描画等を済ませておく
        stim2.draw()
        probe.draw()
        win.flip()
            
        keys = psychopy.event.waitKeys(keyList=['up','down'])
        if series in keys: # 刺激を変化させる場合
            probe_lum += step
            probe.setFillColor([probe_lum, probe_lum, probe_lum])
        elif keys != []:   # 現在の系列を終了させる場合
            datafile.write('{:.2f},{:.2f},{:.2f},{:.2f}\n'.format(
                stim1_lum, start_probe_lum, step, probe_lum))
            in_series = False

    win.flip() #刺激を消去する
    psychopy.core.wait(1.0) #1.0秒待つ

datafile.close() #データファイルを閉じる