#coding:utf-8
from __future__ import division
from __future__ import unicode_literals
import psychopy.visual
import psychopy.event
import psychopy.gui
import psychopy.core
import psychopy.logging
import random
import codecs
import math

param_dict = {
    'Participant':'',
    'Target stimulus':['C_Target','O_Target'],
    '"Present" key':['f','j'],
    'Radius':0.3}

dlg = psychopy.gui.DlgFromDict(param_dict, title='Visual Search')
if not dlg.OK:
    psychopy.core.quit()

participant = param_dict['Participant']
target_stim = param_dict['Target stimulus']
present_key = param_dict['"Present" key']
radius = param_dict['Radius']
if target_stim == 'C_Target':
    base_filename = participant + '_C'
else:
    base_filename = participant + '_O'
data_fp = codecs.open(base_filename+'.csv','w','utf-8')
data_fp.write('items,target,correct,rt\n')

log_file = psychopy.logging.LogFile(base_filename+'.log',
    level=psychopy.logging.EXP, filemode='w')
psychopy.logging.exp('Participant:{}'.format(participant))
psychopy.logging.exp('Target stimulus:{}'.format(target_stim))
psychopy.logging.exp('Present key:{}'.format(present_key))
psychopy.logging.exp('Radius:{}'.format(radius))

conditions = []
for target in ['present', 'absent']:
    for items in [5, 10, 15]:
        conditions.append([target, items])

conditions *= 10
random.shuffle(conditions)

win = psychopy.visual.Window(units='height', fullscr=True)
fix_image = psychopy.visual.Circle(
    win, radius=0.001, fillColor='white', name='fix_image')
if target_stim == 'C_Target':
    target_image = psychopy.visual.ImageStim(
        win, 'c.png', name='target_image')
    distractor_image = psychopy.visual.ImageStim(
        win, 'o.png', name='distractor_image')
else:
    target_image = psychopy.visual.ImageStim(
        win, 'o.png', name='target_image')
    distractor_image = psychopy.visual.ImageStim(
        win, 'c.png', name='distractor_image')
inst_text = psychopy.visual.TextStim(win, height=0.03)
message = '''画面中央の固視点の周辺に図形が複数表示されます．
ひとつだけ異なる図形が含まれていれば  {}
すべて同じ図形であれば  {}  を押してください．
出来るだけ速く正確に押してください．
キーを押すと直ちに次の試行へ進みますが，
20試行毎に休憩することが出来ます．

準備が出来たら  f  か  j  を押して開始してください．'''
if present_key == 'f':
    inst_text.setText(message.format('f','j'))
else:
    inst_text.setText(message.format('j','f'))

clock = psychopy.core.Clock()

inst_text.draw()
win.flip()
key = psychopy.event.waitKeys(keyList=['f','j','escape'])
if 'escape' in key:
    psychopy.core.quit()

for trial in range(len(conditions)):
    if trial!=0 and trial%20==0:
        psychopy.event.getKeys()
        message='''必要であれば休憩してください．
準備が出来たら  f  か  j  を押して開始してください．'''
        inst_text.setText(message)
        inst_text.draw()
        win.flip()
        key = psychopy.event.waitKeys(keyList=['f','j','escape'])
        if 'escape' in key:
            psychopy.core.quit()
    
    fix_image.draw()
    win.flip()
    psychopy.core.wait(random.choice([1.0,1.25,1.5]))
    
    target = conditions[trial][0]
    items = conditions[trial][1]
    
    fix_image.draw()
    
    offset = random.random()*360
    for item in range(items):
        angle = (360.0/items*item+offset)*math.pi/180.0
        pos = (radius*math.cos(angle), radius*math.sin(angle))
        if item==0 and target=='present':
            target_image.setPos(pos)
            target_image.draw()
        else:
            distractor_image.setPos(pos)
            distractor_image.draw()
    
    win.callOnFlip(clock.reset)
    psychopy.event.getKeys()
    win.flip()
    key = psychopy.event.waitKeys(
        keyList=['f','j','escape'], timeStamped=clock)
    
    if key[0][0]=='escape':
        break
    
    rt = key[0][1]*1000
    if (key[0][0] == present_key and target=='present') or (
        key[0][0] != present_key and target=='absent'):
        correct = 1
    else:
        correct = 0
    
    data_fp.write('{},{},{},{:.1f}\n'.format(
        items, target, correct, rt))
    data_fp.flush()
    psychopy.logging.flush()

inst_text.setText('実験は終了しました．ご協力ありがとうございました．')
inst_text.draw()
win.flip()
psychopy.core.wait(2.0)

data_fp.close()
win.close()